@@ -14,8 +14,8 @@ from StringIO import StringIO
 from tempfile import mkstemp
 from os import remove
 
-STATUSES = {0 : 'FAIL',
-            1 : 'COMPLETE',
+STATUSES = {'FAIL':0,
+            'COMPLETE':1,
             }
 
 # shorthand
@@ -62,6 +62,7 @@ class Worker(object):
         self.queue_stdin = queue_stdin
         self.queue_stdout = queue_stdout
         self.context = kw
+        self.stop = False
         if 'start' in kw:
             self.run()
     
@@ -74,6 +75,8 @@ class Worker(object):
     def run(self):
         while (True):
             # Blocking call:
+            if self.stop:
+                break
             msg = self.queue_stdin.get()
             # TODO implement variable timeout on .starttask() method
             resp = self.starttask(msg)
